@@ -6,7 +6,7 @@
 # create their own plate types.
 
 #' Get droplet data from a well
-#' 
+#'
 #' @param plate A ddPCR plate.
 #' @param well_id A well ID.
 #' @param empty Whether or not to include empty droplets.
@@ -19,14 +19,14 @@
 get_single_well <- function(plate, well_id,
                             empty = FALSE, outliers = FALSE, clusters = FALSE) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
-  
+
   well_id %<>% toupper
-  
+
   result <-
     plate_data(plate) %>%
     dplyr::filter_(~ well == well_id) %>%
     dplyr::select_(quote(-well))
-  
+
   if (!empty) {
     result %<>%
       dplyr::filter_(~ cluster != plate %>% cluster('EMPTY'))
@@ -39,7 +39,7 @@ get_single_well <- function(plate, well_id,
     result %<>%
       dplyr::select_(~ -cluster)
   }
-  
+
   result
 }
 
@@ -68,10 +68,10 @@ cat0 <- function(...) {
 }
 
 #' Write a message to the user if the `ddpcr.verbose` option is on
-#' 
+#'
 #' Running a ddpcr analysis results in many messages being printed to the console.
 #' By default, these messages are on when the user is using R interactively
-#' and off otherwise. You can overwrite this setting with \code{options(ddpcr.verbose = FALSE)}. 
+#' and off otherwise. You can overwrite this setting with \code{options(ddpcr.verbose = FALSE)}.
 #' @param ... Parameters to pass to \code{message()}
 #' @keywords internal
 #' @export
@@ -98,7 +98,7 @@ msg <- function(...) {
 #' used to convert that return value into a data.frame.
 #' @param lol List of lists that is a result of a vapply
 #' @param name Column name to use for the name of each list
-#' @examples 
+#' @examples
 #' vapply(c("a", "b", "c"),
 #'        function(x) list(low = x, up = toupper(x)),
 #'        list(character(1), character(1))) %>%
@@ -107,7 +107,7 @@ msg <- function(...) {
 #' @keywords internal
 #' @export
 lol_to_df <- function(lol, name = "well") {
-  lol %<>% t %>% as.data.frame
+  lol %<>% t() %>% as.data.frame(stringsAsFactors = TRUE)
   lol[[name]] <- row.names(lol)
   lol <- move_front(lol, name)
   lol[] <- lapply(lol, unlist)
@@ -116,7 +116,7 @@ lol_to_df <- function(lol, name = "well") {
 }
 
 #' Convert a named vector returned from vapply to a dataframe
-#' 
+#'
 #' When running a \code{vapply} function and each element returns a single value,
 #' the return value is a named vector.  This function can be used to convert
 #' that return value into a data.frame. Similar to \code{\link[ddpcr]{lol_to_df}},
@@ -126,7 +126,7 @@ lol_to_df <- function(lol, name = "well") {
 #' @param v Named vector that is a result of a vapply
 #' @param name Column name to use for the name of each element
 #' @param rowname Column name to use for the values of the rownames
-#' @examples 
+#' @examples
 #' vapply(c("a", "b", "c"),
 #'        toupper,
 #'        character(1)) %>%
@@ -135,7 +135,7 @@ lol_to_df <- function(lol, name = "well") {
 #' @keywords internal
 #' @export
 named_vec_to_df <- function(v, name, rowname = "well") {
-  v <- as.data.frame(v)
+  v <- as.data.frame(v, stringsAsFactors = TRUE)
   colnames(v) <- name
   v[[rowname]] <- row.names(v)
   v
@@ -154,10 +154,10 @@ quiet <- function(expr, all = TRUE) {
   } else {
     file <- "/dev/null"
   }
-  
+
   if (all) {
     suppressWarnings(suppressMessages(suppressPackageStartupMessages(
-      utils::capture.output(expr, file = file) 
+      utils::capture.output(expr, file = file)
     )))
   } else {
     utils::capture.output(expr, file = file)
@@ -165,41 +165,41 @@ quiet <- function(expr, all = TRUE) {
 }
 
 #' Overwrite a column in a data.frame based on a matching column in another df
-#' 
+#'
 #' Sometimes you want to merge two dataframes and specify that column X in
 #' one dataframe should overwrite the same column in the other dataframe.
 #' If there is a missing value in the column in the new dataframe, then the value
 #' from the old dataframe is kept.
-#' 
+#'
 #' @param olddf The dataframe whose column will be overwritten.
 #' @param newdf The dataframe that will use its columns to overwrite.
 #' @param cols The names of the columns that exist in both dataframes that
 #' should be overwritten. If not provided, then all columns that are common
 #' to both dataframes are used.
 #' @param bycol The names of the columns to use as the key for the merge.
-#' @examples 
+#' @examples
 #' df <- function(...) data.frame(..., stringsAsFactors = FALSE)
-#' 
+#'
 #' df1 <- df(a = 1:4, b = c("one", NA, "three", "four"))
 #' df2 <- df(a = 1:4, b = c("ONE", "TWO", NA, "FOUR"))
 #' merge_dfs_overwrite_col(df1, df2, "b", "a")
 #' merge_dfs_overwrite_col(df2, df1, "b", "a")
-#' 
+#'
 #' df3 <- df(a = 1:3, b = c("one", NA, "three"))
 #' df4 <- df(a = 2:4, b = c("TWO", NA, "FOUR"))
 #' merge_dfs_overwrite_col(df3, df4, "b", "a")
 #' merge_dfs_overwrite_col(df4, df3, "b", "a")
-#' 
+#'
 #' df5 <- df(a = 1:3, b = c("one", "two", "three"), c = letters[1:3])
 #' df6 <- df(b = c("ONE", "TWO", "THREE"), c = LETTERS[1:3], a = 1:3)
 #' merge_dfs_overwrite_col(df5, df6, "b", "a")
 #' merge_dfs_overwrite_col(df6, df5, "b", "a")
-#' 
+#'
 #' df7 <- df(a = 1:3, b = c("one", "two", "three"))
 #' df8 <- df(a = 1:4)
 #' merge_dfs_overwrite_col(df7, df8, "b", "a")
 #' merge_dfs_overwrite_col(df8, df7, "b", "a")
-#' 
+#'
 #' df9 <- df(a = 1:3, b = c("one", "two", "three"), c = 1:3)
 #' df10 <- df(a = 1:3, b = c("ONE", NA, "THREE"), c = 4:6)
 #' merge_dfs_overwrite_col(df9, df10, c("b", "c"), "a")
@@ -208,16 +208,16 @@ quiet <- function(expr, all = TRUE) {
 #' @export
 merge_dfs_overwrite_col <- function(olddf, newdf, cols, bycol = "well") {
   result <- dplyr::left_join(olddf, newdf, by = bycol)
-  
+
   # If user didn't specify which columns to keep, keep all original columns
   if (missing(cols)) {
     cols <- setdiff(colnames(olddf), bycol)
   }
-  
+
   for (colname in cols) {
     colname_x <- sprintf("%s.x", colname)
     colname_y <- sprintf("%s.y", colname)
-    
+
     if (all(c(colname_x, colname_y) %in% colnames(result))) {
       result[[colname_x]] <- ifelse(is.na(result[[colname_y]]),
                                     result[[colname_x]],
@@ -227,7 +227,7 @@ merge_dfs_overwrite_col <- function(olddf, newdf, cols, bycol = "well") {
         dplyr::select_(lazyeval::interp(~ -colname, colname = as.name(colname_y)))
     }
   }
-  
+
   result
 }
 
@@ -235,7 +235,7 @@ merge_dfs_overwrite_col <- function(olddf, newdf, cols, bycol = "well") {
 #' @param x Vector of numbers.
 #' @return A vector containing the indices of the elements that are local maxima
 #' in the given input.
-#' @examples 
+#' @examples
 #' local_maxima(c(1, 5, 3, 2, 4, 3))
 #' @keywords internal
 #' @export
@@ -254,7 +254,7 @@ local_maxima <- function(x) {
 #' @param x Vector of numbers.
 #' @return A vector containing the indices of the elements that are local minima
 #' in the given input.
-#' @examples 
+#' @examples
 #' local_minima(c(1, 5, 3, 2, 4, 3))
 #' @keywords internal
 #' @export
@@ -297,7 +297,7 @@ is_file <- function(path) {
 #' Representation of a 2D point
 #' @param x A 2-element numeric vector.
 #' @return An object of class \code{point2d} with the given coordinates.
-#' @examples 
+#' @examples
 #' point2d(c(10, 20))
 #' @keywords internal
 #' @export
@@ -310,7 +310,7 @@ point2d <- function(x) {
 }
 
 #' Euclidean distance between two points
-#' 
+#'
 #' Calculate the distance between two points in 2D space. If only one points is
 #' given, then the distance to the origin is calculated.
 #' @param x,y Points generated with \code{point2d}
@@ -335,13 +335,13 @@ print.point2d <- function(x, ...) {
 }
 
 #' Move columns to the front of a data.frame
-#' 
+#'
 #' This function is taken from daattali/rsalad R package.
-#' 
+#'
 #' @param df A data.frame.
 #' @param cols A vector of column names to move to the front.
-#' @examples 
-#' df <- data.frame(a = character(0), b = character(0), c = character(0))
+#' @examples
+#' df <- data.frame(a = character(0), b = character(0), c = character(0), stringsAsFactors = TRUE)
 #' move_front(df, "b")
 #' move_front(df, c("c", "b"))
 #' @keywords internal
@@ -351,13 +351,13 @@ move_front <- function(df, cols) {
 }
 
 #' Move columns to the back of a data.frame
-#' 
+#'
 #' This function is taken from daattali/rsalad R package.
-#' 
+#'
 #' @param df A data.frame.
 #' @param cols A vector of column names to move to the back
-#' @examples 
-#' df <- data.frame(a = character(0), b = character(0), c = character(0))
+#' @examples
+#' df <- data.frame(a = character(0), b = character(0), c = character(0), stringsAsFactors = TRUE)
 #' move_back(df, "b")
 #' move_back(df, c("b", "a"))
 #' @keywords internal
@@ -374,9 +374,9 @@ bind_df_ends <- function(df, cols, dir = 1) {
     is.data.frame(df),
     cols %in% colnames(df)
   )
-  
+
   is_tbl <- dplyr::is.tbl(df)
-  
+
   # Bind together the two parts of the data.frame
   if (dir == 1) {
     df <-
@@ -394,12 +394,12 @@ bind_df_ends <- function(df, cols, dir = 1) {
     stop("bind_df_ends: dir can only be -1 or 1", call. = FALSE)
   }
 
-  
+
   # If the input was a tbl_df, make sure to return that object too
   if (is_tbl) {
     df <- dplyr::tbl_df(df)
   }
-  
+
   df
 }
 
@@ -409,4 +409,4 @@ bind_df_ends <- function(df, cols, dir = 1) {
 capitalize <- function(x) {
   paste(toupper(substring(x, 1, 1)), substring(x, 2),
         sep = "", collapse = " ")
-}
\ No newline at end of file
+}
